/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.operator.keycloak.user;

import java.util.Optional;

import org.springframework.stereotype.Component;

import io.fabric8.kubernetes.api.model.Secret;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.extension.ResourceAdapter;
import lombok.RequiredArgsConstructor;

@RequiredArgsConstructor
@Component
class UserSecretService {

	private final UserNameConverter userNameConverter;
	private final UserSecretBuilder secretBuilder;
	private final UserSecretReader secretReader;
	private final KubernetesRemoteService kubernetesRemoteService;

	public Secret create(OzgCloudKeycloakUserSpec userSpec, String namespace) {
		var secretName = userNameConverter.toSecretName(userSpec.getKeycloakUser());

		var credentialsSecret = secretBuilder.build(secretName, userSpec.getKeycloakUser(), namespace);

		var adapter = createResourceAdpater(getUserSecret(userSpec, namespace));
		adapter.create(credentialsSecret);

		return credentialsSecret;
	}

	ResourceAdapter<Secret> createResourceAdpater(Resource<Secret> secretResource) {
		return new ResourceAdapter<>(secretResource);
	}

	Resource<Secret> getUserSecret(OzgCloudKeycloakUserSpec userSpec, String namespace) {
		var secretName = userNameConverter.toSecretName(userSpec.getKeycloakUser());

		return kubernetesRemoteService.getSecret(namespace, secretName);
	}

	public String getPasswordFromSecret(Secret secret) {
		return secretReader.getPasswortFromSecret(secret);
	}

	public Secret getOrCreateClusterSecret(OzgCloudKeycloakUserSpec userSpec, String namespace) {
		return Optional.ofNullable(getUserSecret(userSpec, namespace)).map(Resource::get)
				.orElseGet(() -> create(userSpec, namespace));
	}
}
