/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.operator.keycloak.group;

import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import java.util.Optional;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.keycloak.representations.idm.GroupRepresentation;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

class KeycloakGroupServiceTest {

	private static final String REALM = "TestRealm";

	@Spy
	@InjectMocks
	private KeycloakGroupService service;

	@Mock
	private KeycloakGroupRemoteService remoteService;

	@Mock
	private KeycloakGroupMapper mapper;

	@Nested
	class TestCreateGroup {

		private final static OzgCloudKeycloakGroupSpec KEYCLOAK_GROUP = OzgCloudKeycloakGroupSpecTestFactory.create();

		@Test
		void shouldCallGetGroupRemoteService() {
			var groupRepresentation = GroupRepresentationTestFactory.create();
			when(mapper.map(any())).thenReturn(groupRepresentation);

			service.createGroup(KEYCLOAK_GROUP, REALM);

			verify(remoteService).getGroupByName(OzgCloudKeycloakGroupSpecTestFactory.NAME, REALM);
		}

		@Test
		void shouldCallMapper() {

			service.createGroup(KEYCLOAK_GROUP, REALM);

			verify(mapper).map(KEYCLOAK_GROUP);
		}

		@Test
		void shouldCreateGroupIfNotExists() {
			var groupRepresentation = GroupRepresentationTestFactory.create();
			when(remoteService.getGroupByName(OzgCloudKeycloakGroupSpecTestFactory.NAME, REALM)).thenReturn(Optional.empty());
			when(mapper.map(KEYCLOAK_GROUP)).thenReturn(groupRepresentation);

			service.createGroup(KEYCLOAK_GROUP, REALM);

			verify(remoteService).createGroup(groupRepresentation, REALM);
		}

		@Test
		void shouldNotCreateGroupIfAlreadyExists() {
			when(remoteService.getGroupByName(OzgCloudKeycloakGroupSpecTestFactory.NAME, REALM)).thenReturn(Optional.of(mock(GroupRepresentation.class)));
			when(mapper.map(KEYCLOAK_GROUP)).thenReturn(GroupRepresentationTestFactory.create());

			service.createGroup(KEYCLOAK_GROUP, REALM);

			verify(remoteService, never()).createGroup(any(), anyString());
		}
	}
}
