/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.operator.keycloak.user;

import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import io.fabric8.kubernetes.api.model.Secret;
import io.fabric8.kubernetes.api.model.SecretList;
import io.fabric8.kubernetes.client.KubernetesClient;
import io.fabric8.kubernetes.client.dsl.MixedOperation;
import io.fabric8.kubernetes.client.dsl.Resource;

class KubernetesRemoteServiceTest {

	private static final String NAMESPACE = "dummyNamespaceName";

	@InjectMocks
	private KubernetesRemoteService service;
	@Mock
	private KubernetesClient kubernetesClient;

	@DisplayName("Get secret")
	@Nested
	class TestGetSecret {

		private static final String SECRET_NAME = "dummySecretName";

		@Mock
		private MixedOperation<Secret, SecretList, Resource<Secret>> secretsMock;

		@BeforeEach
		void mock() {
			when(kubernetesClient.secrets()).thenReturn(secretsMock);
			when(secretsMock.inNamespace(any())).thenReturn(secretsMock);
		}

		@Test
		void shouldGetFromNamespace() {
			service.getSecret(NAMESPACE, SECRET_NAME);

			verify(secretsMock).inNamespace(NAMESPACE);
		}

		@Test
		void shouldGetWithName() {
			service.getSecret(NAMESPACE, SECRET_NAME);

			verify(secretsMock).withName(SECRET_NAME);
		}
	}
}
