/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.operator.keycloak.user;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.ValueSource;
import org.mockito.Spy;

class UserNameConverterTest {

	@Spy
	private UserNameConverter converter = new UserNameConverter();

	@DisplayName("To secretName")
	@Nested
	class TestToSecretName {

		@Test
		void shouldReturnName() {
			var secretName = converter.toSecretName(KeycloakUserSpecUserTestFactory.create());

			assertThat(secretName).isEqualTo(KeycloakUserSpecUserTestFactory.USERNAME.toLowerCase() + "-credentials");
		}

		@Test
		void shouldClarifyUserName() {
			converter.toSecretName(KeycloakUserSpecUserTestFactory.create());

			verify(converter).clarifyName(KeycloakUserSpecUserTestFactory.USERNAME.toLowerCase());
		}

		@DisplayName("clarify name")
		@Nested
		class TestClarifyName {

			@ValueSource(strings = { "_user_name_", ".user.name.", "-user-name-" })
			@ParameterizedTest
			void shouldReplaceForbiddenCharacter(String userName) {
				var clarifiedName = converter.clarifyName(userName);

				assertThat(clarifiedName).isEqualTo("username");
			}
		}
	}
}