/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.operator.keycloak.user;

import static org.assertj.core.api.Assertions.*;

import java.util.Base64;
import java.util.Map;

import org.junit.jupiter.api.Test;
import org.mockito.Spy;

import io.fabric8.kubernetes.api.model.Secret;
import io.fabric8.kubernetes.api.model.SecretBuilder;

class UserSecretReaderTest {

	@Spy
	private UserSecretReader reader;

	@Test
	void shouldReturnPasssowrd() {
		Secret secret = buildSecret();

		String password = reader.getPasswortFromSecret(secret);

		assertThat(password).isEqualTo(SecretTestFactory.PASSWORD);
	}

	private Secret buildSecret() {
		return new SecretBuilder()
				.addToData(Map.of(UserSecretBuilder.SECRET_PASSWORD_FIELD,
						encodeStringBase64(SecretTestFactory.PASSWORD)))
				.build();
	}

	private String encodeStringBase64(String string) {
		return Base64.getEncoder().encodeToString(string.getBytes());
	}
}
